<?php

namespace Drupal\cctags\Form;

use Drupal\block\Entity\Block;
use Drupal\Core\Database\Database;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class LoginDisableSettingsForm.
 *
 * @package Drupal\cctags\Form
 */
class CctagsDeleteItemForm extends ConfirmFormBase {

  /**
   * Returns the entity_type.manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityManager;

  /**
   * The ID of the item to delete.
   *
   * @var string
   */
  protected $cctid;

  /**
   * {@inheritdoc}
   */
  public function __construct(EntityTypeManagerInterface $entity_manager) {
    $this->entityManager = $entity_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('cctags.settings_form');
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cctags_delete_item_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Do you want to delete?');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelText() {
    return $this->t('Cancel');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $cctid = NULL) {
    $this->cctid = $cctid;
    // $form = array();
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $connection = Database::getConnection();

    $block = Block::load('cctagsblock_' . $this->cctid);
    if ($block) {
      $this->entityManager->getStorage('block')->delete(['cctagsblock_' . $this->cctid => $block]);
    }

    $connection->delete('cctags')
      ->condition('cctid', $this->cctid)
      ->execute();

    $form_state->setRedirect('cctags.settings_form');
  }

}
